@@ -32,8 +32,7 @@ _DEPRECATION_MSG = '%s has been deprecated in the Newton release. ' \
 
 def _order_not_found():
     """Throw exception indicating order not found."""
-    pecan.abort(404, u._('Not Found. Sorry but your order is in '
-                         'another castle.'))
+    pecan.abort(404, u._('Order not found.'))
 
 
 def _secret_not_in_order():
@@ -62,11 +61,18 @@ class OrderController(controllers.ACLMixin):
     """Handles Order retrieval and deletion requests."""
 
     def __init__(self, order, queue_resource=None):
+        super().__init__()
         self.order = order
         self.order_repo = repo.get_order_repository()
         self.queue = queue_resource or async_client.TaskClient()
         self.type_order_validator = validators.TypeOrderValidator()
 
+    def get_acl_tuple(self, req, **kwargs):
+        acl = dict()
+        acl['project_id'] = self.order.project.external_id
+        acl['creator_id'] = self.order.creator_id
+        return 'order', acl
+
     @pecan.expose(generic=True)
     def index(self, **kwargs):
         pecan.abort(405)  # HTTP 405 Method Not Allowed as default
@@ -91,8 +97,8 @@ class OrdersController(controllers.ACLMixin):
     """Handles Order requests for Secret creation."""
 
     def __init__(self, queue_resource=None):
-
         LOG.debug('Creating OrdersController')
+        super().__init__()
         self.order_repo = repo.get_order_repository()
         self.queue = queue_resource or async_client.TaskClient()
         self.type_order_validator = validators.TypeOrderValidator()
@@ -108,7 +114,7 @@ class OrdersController(controllers.ACLMixin):
         ctx = controllers._get_barbican_context(pecan.request)
 
         order = self.order_repo.get(entity_id=order_id,
-                                    external_project_id=ctx.project,
+                                    external_project_id=ctx.project_id,
                                     suppress_exception=True)
         if not order:
             _order_not_found()
@@ -182,7 +188,7 @@ class OrdersController(controllers.ACLMixin):
         request_id = None
         ctxt = controllers._get_barbican_context(pecan.request)
         if ctxt:
-            new_order.creator_id = ctxt.user
+            new_order.creator_id = ctxt.user_id
             request_id = ctxt.request_id
 
         self.order_repo.create_from(new_order)
