@@ -11,12 +11,13 @@
 #  WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #  License for the specific language governing permissions and limitations
 #  under the License.
+
 import argparse
 import base64
-import json
 import traceback
 
 from oslo_db.sqlalchemy import session
+from oslo_serialization import jsonutils as json
 from sqlalchemy import orm
 from sqlalchemy.orm import scoping
 
@@ -60,7 +61,7 @@ class KekSignatureMigrator(object):
                 self.pkcs11.verify_hmac(hmac_key, hmac, kek_data, self.session)
                 sig_good = True
             except P11CryptoPluginException as e:
-                if 'CKR_SIGNATURE_INVALID' in e.message:
+                if 'CKR_SIGNATURE_INVALID' in str(e):
                     sig_good = False
                 else:
                     raise
@@ -78,7 +79,7 @@ class KekSignatureMigrator(object):
                 )
                 sig_bad = True
             except P11CryptoPluginException as e:
-                if 'CKR_SIGNATURE_INVALID' in e.message:
+                if 'CKR_SIGNATURE_INVALID' in str(e):
                     sig_bad = False
                 else:
                     raise
@@ -165,5 +166,6 @@ def main():
     )
     migrator.execute(args.dry_run)
 
+
 if __name__ == '__main__':
     main()
