@@ -38,7 +38,6 @@ import pki.key as key
 import pki.kra
 import pki.profile
 from requests import exceptions as request_exceptions
-import six
 
 from barbican.common import exception
 from barbican.common import utils
@@ -94,7 +93,7 @@ def _setup_nss_db_services(conf):
         return None
     if nss_password is None:
         raise ValueError(u._("nss_password is required"))
-    if type(nss_password) is not six.binary_type:
+    if type(nss_password) is not bytes:
         # Password needs to be a bytes object in Python 3
         nss_password = nss_password.encode('UTF-8')
 
@@ -115,6 +114,7 @@ def _import_kra_transport_cert_to_nss_db(conf, crypto):
         transport_cert = systemcert_client.get_transport_cert()
         crypto.import_cert(KRA_TRANSPORT_NICK, transport_cert, ",,")
     except Exception as e:
+        LOG.debug("Error importing KRA transport cert.", exc_info=True)
         LOG.error("Error in importing transport cert."
                   " KRA may not be enabled: %s", e)
 
@@ -132,6 +132,7 @@ def create_connection(conf, subsystem_path):
     connection.set_authentication_cert(pem_path)
     return connection
 
+
 crypto = _setup_nss_db_services(CONF)
 if crypto:
     crypto.initialize()
@@ -665,7 +666,7 @@ def _catch_subca_deletion_exceptions(ca_related_function):
     def _catch_subca_exception(self, *args, **kwargs):
         try:
             return ca_related_function(self, *args, **kwargs)
-        except pki.ResourceNotFoundException as e:
+        except pki.ResourceNotFoundException:
             LOG.warning("Sub-CA already deleted")
             pass
         except pki.PKIException as e:
