@@ -18,8 +18,6 @@ Task resources for the Barbican API.
 """
 import abc
 
-import six
-
 from barbican import api
 from barbican.common import utils
 from barbican import i18n as u
@@ -33,8 +31,7 @@ from barbican.tasks import common
 LOG = utils.getLogger(__name__)
 
 
-@six.add_metaclass(abc.ABCMeta)
-class BaseTask(object):
+class BaseTask(object, metaclass=abc.ABCMeta):
     """Base asynchronous task."""
 
     @abc.abstractmethod
@@ -67,10 +64,8 @@ class BaseTask(object):
         try:
             return self.process(*args, **kwargs)
         except Exception:
-            LOG.exception(
-                u._LE(
-                    "Suppressing exception while trying to "
-                    "process task '%s'."), self.get_name())
+            LOG.exception("Suppressing exception while trying to "
+                          "process task '%s'.", self.get_name())
 
     def process(self, *args, **kwargs):
         """A template method for all asynchronous tasks.
@@ -93,16 +88,15 @@ class BaseTask(object):
             entity = self.retrieve_entity(*args, **kwargs)
         except Exception:
             # Serious error!
-            LOG.exception(u._LE("Could not retrieve information needed to "
-                                "process task '%s'."), name)
+            LOG.exception("Could not retrieve information needed to "
+                          "process task '%s'.", name)
             raise
 
         # Process the target entity.
         try:
             result = self.handle_processing(entity, *args, **kwargs)
         except Exception as e_orig:
-            LOG.exception(u._LE("Could not perform processing for "
-                                "task '%s'."), name)
+            LOG.exception("Could not perform processing for task '%s'.", name)
 
             # Handle failure to process entity.
             try:
@@ -111,19 +105,17 @@ class BaseTask(object):
                 self.handle_error(entity, status, message, e_orig,
                                   *args, **kwargs)
             except Exception:
-                LOG.exception(u._LE("Problem handling an error for task '%s', "
-                                    "raising original "
-                                    "exception."), name)
+                LOG.exception("Problem handling an error for task '%s', "
+                              "raising original exception.", name)
             raise e_orig
 
         # Handle successful conclusion of processing.
         try:
             self.handle_success(entity, result, *args, **kwargs)
         except Exception:
-            LOG.exception(u._LE("Could not process after successfully "
-                                "executing task '%s'."), name)
+            LOG.exception("Could not process after successfully "
+                          "executing task '%s'.", name)
             raise
-
         return result
 
     @abc.abstractmethod
@@ -241,7 +233,7 @@ class BeginTypeOrder(BaseTask):
 
     def __init__(self):
         super(BeginTypeOrder, self).__init__()
-        LOG.debug(u._('Creating BeginTypeOrder task processor'))
+        LOG.debug('Creating BeginTypeOrder task processor')
         self.project_repo = rep.get_project_repository()
         self.helper = _OrderTaskHelper()
 
@@ -286,7 +278,7 @@ class BeginTypeOrder(BaseTask):
                 project
             )
             order.secret_id = new_secret.id
-            LOG.debug(u._("...done creating keys order's secret."))
+            LOG.debug("...done creating keys order's secret.")
         elif order_type == models.OrderType.ASYMMETRIC:
             # Create asymmetric Secret
             new_container = plugin.generate_asymmetric_secret(
@@ -295,14 +287,14 @@ class BeginTypeOrder(BaseTask):
                               'application/octet-stream'),
                 project)
             order.container_id = new_container.id
-            LOG.debug(u._("...done creating asymmetric order's secret."))
+            LOG.debug("...done creating asymmetric order's secret.")
         elif order_type == models.OrderType.CERTIFICATE:
             # Request a certificate
             new_container = cert.issue_certificate_request(
                 order, project, result_follow_on)
             if new_container:
                 order.container_id = new_container.id
-            LOG.debug(u._("...done requesting a certificate."))
+            LOG.debug("...done requesting a certificate.")
         else:
             raise NotImplementedError(
                 u._('Order type "{order_type}" not implemented.').format(
@@ -327,7 +319,7 @@ class UpdateOrder(BaseTask):
 
     def __init__(self):
         super(UpdateOrder, self).__init__()
-        LOG.debug(u._('Creating UpdateOrder task processor'))
+        LOG.debug('Creating UpdateOrder task processor')
         self.helper = _OrderTaskHelper()
 
     def retrieve_entity(self, *args, **kwargs):
@@ -349,13 +341,13 @@ class UpdateOrder(BaseTask):
         if order_type == models.OrderType.CERTIFICATE:
             # Update a certificate request
             cert.modify_certificate_request(order, updated_meta)
-            LOG.debug(u._("...done updating a certificate order."))
+            LOG.debug("...done updating a certificate order.")
         else:
             raise NotImplementedError(
                 u._('Order type "{order_type}" not implemented.').format(
                     order_type=order_type))
 
-        LOG.debug(u._("...done updating order."))
+        LOG.debug("...done updating order.")
 
     def handle_error(self, order, status, message, exception,
                      *args, **kwargs):
@@ -374,7 +366,7 @@ class CheckCertificateStatusOrder(BaseTask):
         return u._('Check Certificate Order Status')
 
     def __init__(self):
-        LOG.debug(u._('Creating CheckCertificateStatusOrder task processor'))
+        LOG.debug('Creating CheckCertificateStatusOrder task processor')
         self.project_repo = rep.get_project_repository()
         self.helper = _OrderTaskHelper()
 
@@ -410,7 +402,7 @@ class CheckCertificateStatusOrder(BaseTask):
             order, project, result_follow_on)
         if new_container:
             order.container_id = new_container.id
-        LOG.debug(u._("...done checking status of a certificate order."))
+        LOG.debug("...done checking status of a certificate order.")
 
         return result_follow_on
 
