@@ -16,7 +16,6 @@
 import datetime
 from oslo_serialization import base64 as oslo_base64
 from oslo_serialization import jsonutils as json
-import six
 import sys
 import testtools
 import time
@@ -465,7 +464,7 @@ class SecretsTestCase(base.TestCase):
 
         Launchpad bug #1315498
         """
-        data = u'\U0001F37A'
+        data = '\U0001F37A'
         data = data.encode('utf-8')
         test_model = secret_models.SecretModel(
             **self.default_secret_create_two_phase_data)
@@ -884,8 +883,8 @@ class SecretsTestCase(base.TestCase):
         'array': [['boom']],
         'int': [123],
         'none': [None],
-        'bad_character': [six.unichr(0x0080)],
-        'bad_characters': [six.unichr(0x1111) + six.unichr(0xffff)]
+        'bad_character': [chr(0x0080)],
+        'bad_characters': [chr(0x1111) + chr(0xffff)]
     })
     @testcase.attr('negative')
     def test_secret_create_defaults_invalid_payload(self, payload):
@@ -1034,16 +1033,16 @@ class SecretsTestCase(base.TestCase):
 
     @utils.parameterized_dataset({
         'invalid_http_content_type_characaters_latin': {
-            'http_content_type': u'\u00c4'.encode('utf-8')},
+            'http_content_type': '\u00c4'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_arabic': {
-            'http_content_type': u'\u060f'.encode('utf-8')},
+            'http_content_type': '\u060f'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_cyrillic': {
-            'http_content_type': u'\u0416'.encode('utf-8')},
+            'http_content_type': '\u0416'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_replacement_character': {
-            'http_content_type': u'\ufffd'.encode('utf-8')},
+            'http_content_type': '\ufffd'.encode('utf-8')},
     })
     @testcase.attr('negative')
     def test_secret_create_with_invalid_http_content_type_characters(
@@ -1062,16 +1061,16 @@ class SecretsTestCase(base.TestCase):
 
     @utils.parameterized_dataset({
         'invalid_http_content_type_characaters_latin': {
-            'payload_content_type': u'\u00c4'.encode('utf-8')},
+            'payload_content_type': '\u00c4'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_arabic': {
-            'payload_content_type': u'\u060f'.encode('utf-8')},
+            'payload_content_type': '\u060f'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_cyrillic': {
-            'payload_content_type': u'\u0416'.encode('utf-8')},
+            'payload_content_type': '\u0416'.encode('utf-8')},
 
         'invalid_http_content_type_characaters_replacement_character': {
-            'payload_content_type': u'\ufffd'.encode('utf-8')},
+            'payload_content_type': '\ufffd'.encode('utf-8')},
     })
     @testcase.attr('negative')
     def test_secret_create_with_invalid_payload_content_type_characters(
